@@ -63,7 +63,7 @@ LSIconBoxConf *ls_iconboxconf_create_configwin(LSIconBoxWin *plsibw)
   /* END GLOBAL									*/
 
   /* START first frame								*/
-  pFrame = GTK_FRAME(xfce_framebox_new ("Alignment", TRUE));
+  pFrame = GTK_FRAME(xfce_framebox_new (_("Alignment"), TRUE));
   gtk_box_pack_start(GTK_BOX(pp->widgets.main), GTK_WIDGET(pFrame),
     FALSE, FALSE, 0);
   pp->widgets.frame_1		= GTK_VBOX(gtk_vbox_new(FALSE, 0));
